[![Tests](https://github.com/openpathsampling/openpathsampling/workflows/Tests/badge.svg?branch=master)](https://github.com/openpathsampling/openpathsampling/actions?query=workflow%3ATests)
[![codecov](https://codecov.io/gh/openpathsampling/openpathsampling/branch/master/graph/badge.svg?token=9W18VHasdb)](https://codecov.io/gh/openpathsampling/openpathsampling)

# OpenPathSampling

An open source Python framework for transition interface and path sampling
calculations.

See documentation here:

http://openpathsampling.org
